@@ -1,19 +1,18 @@
-from dagster import Field, Float, Noneable, StringSource
-from dagster.core.host_representation import IN_PROCESS_NAME
-from dagster.utils import merge_dicts
 from dagster_celery.executor import CELERY_CONFIG
 from dagster_k8s import DagsterK8sJobConfig
 from dagster_k8s.client import DEFAULT_WAIT_TIMEOUT
 
+from dagster import Field, Float, Noneable, StringSource
+from dagster.core.host_representation import IN_PROCESS_NAME
+from dagster.utils import merge_dicts
+
 CELERY_K8S_CONFIG_KEY = "celery-k8s"
 
 
-def celery_k8s_config():
+def celery_k8s_executor_config():
 
     # DagsterK8sJobConfig provides config schema for specifying Dagster K8s Jobs
-    job_config = DagsterK8sJobConfig.config_type_pipeline_run(
-        default_image_pull_policy="IfNotPresent"
-    )
+    job_config = DagsterK8sJobConfig.config_type_job()
 
     additional_config = {
         "load_incluster_config": Field(
@@ -58,35 +57,31 @@ def celery_k8s_config():
     return cfg
 
 
-def get_celery_engine_config(additional_env_config_maps=None):
+def get_celery_engine_config(image_pull_policy=None, additional_env_config_maps=None):
+    job_config = get_celery_engine_job_config(image_pull_policy, additional_env_config_maps)
+    return {"execution": {CELERY_K8S_CONFIG_KEY: {"config": job_config["execution"]["config"]}}}
+
+
+def get_celery_engine_job_config(image_pull_policy=None, additional_env_config_maps=None):
     return {
         "execution": {
-            CELERY_K8S_CONFIG_KEY: {
-                "config": {
-                    "job_image": {"env": "DAGSTER_K8S_PIPELINE_RUN_IMAGE"},
+            "config": merge_dicts(
+                {
                     "job_namespace": {"env": "DAGSTER_K8S_PIPELINE_RUN_NAMESPACE"},
-                    "image_pull_policy": {"env": "DAGSTER_K8S_PIPELINE_RUN_IMAGE_PULL_POLICY"},
                     "env_config_maps": (
                         [
                             {"env": "DAGSTER_K8S_PIPELINE_RUN_ENV_CONFIGMAP"},
                         ]
                         + (additional_env_config_maps if additional_env_config_maps else [])
                     ),
-                }
-            }
-        }
-    }
-
-
-def get_celery_engine_grpc_config():
-    return {
-        "execution": {
-            CELERY_K8S_CONFIG_KEY: {
-                "config": {
-                    "job_namespace": {"env": "DAGSTER_K8S_PIPELINE_RUN_NAMESPACE"},
-                    "image_pull_policy": {"env": "DAGSTER_K8S_PIPELINE_RUN_IMAGE_PULL_POLICY"},
-                    "env_config_maps": [{"env": "DAGSTER_K8S_PIPELINE_RUN_ENV_CONFIGMAP"}],
-                }
-            }
+                },
+                (
+                    {
+                        "image_pull_policy": image_pull_policy,
+                    }
+                    if image_pull_policy
+                    else {}
+                ),
+            )
         }
     }
