@@ -4,25 +4,6 @@ import sys
 import time
 
 import kubernetes
-from dagster import (
-    DagsterEvent,
-    DagsterEventType,
-    DagsterInstance,
-    EventMetadataEntry,
-    Executor,
-    check,
-    executor,
-    multiple_process_executor_requirements,
-)
-from dagster.cli.api import ExecuteStepArgs
-from dagster.core.errors import DagsterUnmetExecutorRequirementsError
-from dagster.core.events import EngineEventData
-from dagster.core.events.log import EventLogEntry
-from dagster.core.execution.plan.objects import StepFailureData, UserFailureData
-from dagster.core.execution.retries import RetryMode
-from dagster.core.storage.pipeline_run import PipelineRun, PipelineRunStatus
-from dagster.serdes import pack_value, serialize_dagster_namedtuple, unpack_value
-from dagster.utils.error import serializable_error_info_from_exc_info
 from dagster_celery.config import DEFAULT_CONFIG, dict_wrapper
 from dagster_celery.core_execution_loop import DELEGATE_MARKER
 from dagster_celery.defaults import broker_url, result_backend
@@ -41,19 +22,32 @@ from dagster_k8s.job import (
 )
 from dagster_k8s.utils import (
     delete_job,
-    filter_dagster_events_from_pod_logs,
     get_pod_names_in_job,
     retrieve_pod_logs,
     wait_for_job_success,
 )
 
-from .config import CELERY_K8S_CONFIG_KEY, celery_k8s_config
+from dagster import DagsterEvent, DagsterEventType, DagsterInstance, Executor, MetadataEntry
+from dagster import _check as check
+from dagster import executor, multiple_process_executor_requirements
+from dagster.cli.api import ExecuteStepArgs
+from dagster.core.errors import DagsterUnmetExecutorRequirementsError
+from dagster.core.events import EngineEventData
+from dagster.core.events.log import EventLogEntry
+from dagster.core.events.utils import filter_dagster_events_from_cli_logs
+from dagster.core.execution.plan.objects import StepFailureData, UserFailureData
+from dagster.core.execution.retries import RetryMode
+from dagster.core.storage.pipeline_run import PipelineRun, PipelineRunStatus
+from dagster.serdes import pack_value, serialize_dagster_namedtuple, unpack_value
+from dagster.utils.error import serializable_error_info_from_exc_info
+
+from .config import CELERY_K8S_CONFIG_KEY, celery_k8s_executor_config
 from .launcher import CeleryK8sRunLauncher
 
 
 @executor(
     name=CELERY_K8S_CONFIG_KEY,
-    config_schema=celery_k8s_config(),
+    config_schema=celery_k8s_executor_config(),
     requirements=multiple_process_executor_requirements(),
 )
 def celery_k8s_job_executor(init_context):
@@ -63,7 +57,7 @@ def celery_k8s_job_executor(init_context):
     the ``config_source`` key. This config corresponds to the "new lowercase settings" introduced
     in Celery version 4.0 and the object constructed from config will be passed to the
     :py:class:`celery.Celery` constructor as its ``config_source`` argument.
-    (See https://docs.celeryproject.org/en/latest/userguide/configuration.html for details.)
+    (See https://docs.celeryq.dev/en/stable/userguide/configuration.html for details.)
 
     The executor also exposes the ``broker``, `backend`, and ``include`` arguments to the
     :py:class:`celery.Celery` constructor.
@@ -112,18 +106,8 @@ def celery_k8s_job_executor(init_context):
             "CeleryK8sRunLauncher on your instance to use it.",
         )
 
-    job_config = DagsterK8sJobConfig(
-        dagster_home=run_launcher.dagster_home,
-        instance_config_map=run_launcher.instance_config_map,
-        postgres_password_secret=run_launcher.postgres_password_secret,
-        job_image=exc_cfg.get("job_image") or os.getenv("DAGSTER_CURRENT_IMAGE"),
-        image_pull_policy=exc_cfg.get("image_pull_policy"),
-        image_pull_secrets=exc_cfg.get("image_pull_secrets"),
-        service_account_name=exc_cfg.get("service_account_name"),
-        env_config_maps=exc_cfg.get("env_config_maps"),
-        env_secrets=exc_cfg.get("env_secrets"),
-        volume_mounts=exc_cfg.get("volume_mounts"),
-        volumes=exc_cfg.get("volumes"),
+    job_config = run_launcher.get_k8s_job_config(
+        job_image=exc_cfg.get("job_image") or os.getenv("DAGSTER_CURRENT_IMAGE"), exc_config=exc_cfg
     )
 
     # Set on the instance but overrideable here
@@ -194,11 +178,11 @@ class CeleryK8sJobExecutor(Executor):
     def retries(self):
         return self._retries
 
-    def execute(self, pipeline_context, execution_plan):
+    def execute(self, plan_context, execution_plan):
         from dagster_celery.core_execution_loop import core_celery_execution_loop
 
         return core_celery_execution_loop(
-            pipeline_context, execution_plan, step_execution_fn=_submit_task_k8s_job
+            plan_context, execution_plan, step_execution_fn=_submit_task_k8s_job
         )
 
     def app_args(self):
@@ -211,22 +195,22 @@ class CeleryK8sJobExecutor(Executor):
         }
 
 
-def _submit_task_k8s_job(app, pipeline_context, step, queue, priority, known_state):
+def _submit_task_k8s_job(app, plan_context, step, queue, priority, known_state):
     user_defined_k8s_config = get_user_defined_k8s_config(step.tags)
 
-    pipeline_origin = pipeline_context.reconstructable_pipeline.get_python_origin()
+    pipeline_origin = plan_context.reconstructable_pipeline.get_python_origin()
 
     execute_step_args = ExecuteStepArgs(
         pipeline_origin=pipeline_origin,
-        pipeline_run_id=pipeline_context.pipeline_run.run_id,
+        pipeline_run_id=plan_context.pipeline_run.run_id,
         step_keys_to_execute=[step.key],
-        instance_ref=pipeline_context.instance.get_ref(),
-        retry_mode=pipeline_context.executor.retries.for_inner_plan(),
+        instance_ref=plan_context.instance.get_ref(),
+        retry_mode=plan_context.executor.retries.for_inner_plan(),
         known_state=known_state,
         should_verify_step=True,
     )
 
-    job_config = pipeline_context.executor.job_config
+    job_config = plan_context.executor.job_config
     if not job_config.job_image:
         job_config = job_config.with_image(pipeline_origin.repository_origin.container_image)
 
@@ -237,11 +221,11 @@ def _submit_task_k8s_job(app, pipeline_context, step, queue, priority, known_sta
     task_signature = task.si(
         execute_step_args_packed=pack_value(execute_step_args),
         job_config_dict=job_config.to_dict(),
-        job_namespace=pipeline_context.executor.job_namespace,
+        job_namespace=plan_context.executor.job_namespace,
         user_defined_k8s_config_dict=user_defined_k8s_config.to_dict(),
-        load_incluster_config=pipeline_context.executor.load_incluster_config,
-        job_wait_timeout=pipeline_context.executor.job_wait_timeout,
-        kubeconfig_file=pipeline_context.executor.kubeconfig_file,
+        load_incluster_config=plan_context.executor.load_incluster_config,
+        job_wait_timeout=plan_context.executor.job_wait_timeout,
+        kubeconfig_file=plan_context.executor.kubeconfig_file,
     )
 
     return task_signature.apply_async(
@@ -262,7 +246,6 @@ def construct_step_failure_event_and_handle(pipeline_run, step_key, err, instanc
         ),
     )
     event_record = EventLogEntry(
-        message=str(err),
         user_message=str(err),
         level=logging.ERROR,
         pipeline_name=pipeline_run.pipeline_name,
@@ -341,8 +324,8 @@ def create_k8s_job_task(celery_app, **task_kwargs):
             pipeline_run,
             EngineEventData(
                 [
-                    EventMetadataEntry.text(celery_worker_name, "Celery worker name"),
-                    EventMetadataEntry.text(celery_pod_name, "Celery worker Kubernetes Pod name"),
+                    MetadataEntry("Celery worker name", value=celery_worker_name),
+                    MetadataEntry("Celery worker Kubernetes Pod name", value=celery_pod_name),
                 ]
             ),
             CeleryK8sJobExecutor,
@@ -355,7 +338,7 @@ def create_k8s_job_task(celery_app, **task_kwargs):
                 pipeline_run,
                 EngineEventData(
                     [
-                        EventMetadataEntry.text(step_key, "Step key"),
+                        MetadataEntry("Step key", value=step_key),
                     ]
                 ),
                 CeleryK8sJobExecutor,
@@ -370,17 +353,26 @@ def create_k8s_job_task(celery_app, **task_kwargs):
 
         if retry_state.get_attempt_count(step_key):
             attempt_number = retry_state.get_attempt_count(step_key)
-            job_name = "dagster-job-%s-%d" % (k8s_name_key, attempt_number)
-            pod_name = "dagster-job-%s-%d" % (k8s_name_key, attempt_number)
+            job_name = "dagster-step-%s-%d" % (k8s_name_key, attempt_number)
+            pod_name = "dagster-step-%s-%d" % (k8s_name_key, attempt_number)
         else:
-            job_name = "dagster-job-%s" % (k8s_name_key)
-            pod_name = "dagster-job-%s" % (k8s_name_key)
+            job_name = "dagster-step-%s" % (k8s_name_key)
+            pod_name = "dagster-step-%s" % (k8s_name_key)
 
-        input_json = serialize_dagster_namedtuple(execute_step_args)
-        args = ["dagster", "api", "execute_step", input_json]
+        args = execute_step_args.get_command_args()
 
         job = construct_dagster_k8s_job(
-            job_config, args, job_name, user_defined_k8s_config, pod_name
+            job_config,
+            args,
+            job_name,
+            user_defined_k8s_config,
+            pod_name,
+            component="step_worker",
+            labels={
+                "dagster/job": pipeline_run.pipeline_name,
+                "dagster/op": step_key,
+                "dagster/run-id": execute_step_args.pipeline_run_id,
+            },
         )
 
         # Running list of events generated from this task execution
@@ -389,19 +381,17 @@ def create_k8s_job_task(celery_app, **task_kwargs):
         # Post event for starting execution
         job_name = job.metadata.name
         engine_event = instance.report_engine_event(
-            "Executing step {} in Kubernetes job {}".format(step_key, job_name),
+            'Executing step "{}" in Kubernetes job {}.'.format(step_key, job_name),
             pipeline_run,
             EngineEventData(
                 [
-                    EventMetadataEntry.text(step_key, "Step key"),
-                    EventMetadataEntry.text(job_name, "Kubernetes Job name"),
-                    EventMetadataEntry.text(job_config.job_image, "Job image"),
-                    EventMetadataEntry.text(job_config.image_pull_policy, "Image pull policy"),
-                    EventMetadataEntry.text(
-                        str(job_config.image_pull_secrets), "Image pull secrets"
-                    ),
-                    EventMetadataEntry.text(
-                        str(job_config.service_account_name), "Service account name"
+                    MetadataEntry("Step key", value=step_key),
+                    MetadataEntry("Kubernetes Job name", value=job_name),
+                    MetadataEntry("Job image", value=job_config.job_image),
+                    MetadataEntry("Image pull policy", value=job_config.image_pull_policy),
+                    MetadataEntry("Image pull secrets", value=str(job_config.image_pull_secrets)),
+                    MetadataEntry(
+                        "Service account name", value=str(job_config.service_account_name)
                     ),
                 ],
                 marker_end=DELEGATE_MARKER,
@@ -423,8 +413,8 @@ def create_k8s_job_task(celery_app, **task_kwargs):
                     pipeline_run,
                     EngineEventData(
                         [
-                            EventMetadataEntry.text(step_key, "Step key"),
-                            EventMetadataEntry.text(job_name, "Kubernetes Job name"),
+                            MetadataEntry("Step key", value=step_key),
+                            MetadataEntry("Kubernetes Job name", value=job_name),
                         ],
                         marker_end=DELEGATE_MARKER,
                     ),
@@ -438,7 +428,7 @@ def create_k8s_job_task(celery_app, **task_kwargs):
                     pipeline_run,
                     EngineEventData(
                         [
-                            EventMetadataEntry.text(step_key, "Step key"),
+                            MetadataEntry("Step key", value=step_key),
                         ],
                         error=serializable_error_info_from_exc_info(sys.exc_info()),
                     ),
@@ -466,9 +456,9 @@ def create_k8s_job_task(celery_app, **task_kwargs):
                 pipeline_run,
                 EngineEventData(
                     [
-                        EventMetadataEntry.text(step_key, "Step key"),
-                        EventMetadataEntry.text(job_name, "Kubernetes Job name"),
-                        EventMetadataEntry.text(job_namespace, "Kubernetes Job namespace"),
+                        MetadataEntry("Step key", value=step_key),
+                        MetadataEntry("Kubernetes Job name", value=job_name),
+                        MetadataEntry("Kubernetes Job namespace", value=job_namespace),
                     ]
                 ),
                 CeleryK8sJobExecutor,
@@ -483,14 +473,14 @@ def create_k8s_job_task(celery_app, **task_kwargs):
             # a retry boundary. We still catch it here just in case we missed one so that we can
             # report it to the event log
             kubernetes.client.rest.ApiException,
-        ) as err:
+        ):
             instance.report_engine_event(
                 "Encountered unexpected error while waiting on Kubernetes job {} for step {}, "
                 "exiting.".format(job_name, step_key),
                 pipeline_run,
                 EngineEventData(
                     [
-                        EventMetadataEntry.text(step_key, "Step key"),
+                        MetadataEntry("Step key", value=step_key),
                     ],
                     error=serializable_error_info_from_exc_info(sys.exc_info()),
                 ),
@@ -501,14 +491,14 @@ def create_k8s_job_task(celery_app, **task_kwargs):
 
         try:
             pod_names = get_pod_names_in_job(job_name, namespace=job_namespace)
-        except kubernetes.client.rest.ApiException as e:
+        except kubernetes.client.rest.ApiException:
             instance.report_engine_event(
                 "Encountered unexpected error retreiving Pods for Kubernetes job {} for step {}, "
                 "exiting.".format(job_name, step_key),
                 pipeline_run,
                 EngineEventData(
                     [
-                        EventMetadataEntry.text(step_key, "Step key"),
+                        MetadataEntry("Step key", value=step_key),
                     ],
                     error=serializable_error_info_from_exc_info(sys.exc_info()),
                 ),
@@ -521,7 +511,7 @@ def create_k8s_job_task(celery_app, **task_kwargs):
         engine_event = instance.report_engine_event(
             "Retrieving logs from Kubernetes Job pods",
             pipeline_run,
-            EngineEventData([EventMetadataEntry.text("\n".join(pod_names), "Pod names")]),
+            EngineEventData([MetadataEntry("Pod names", value="\n".join(pod_names))]),
             CeleryK8sJobExecutor,
             step_key=step_key,
         )
@@ -532,7 +522,7 @@ def create_k8s_job_task(celery_app, **task_kwargs):
             try:
                 raw_logs = retrieve_pod_logs(pod_name, namespace=job_namespace)
                 logs += raw_logs.split("\n")
-            except kubernetes.client.rest.ApiException as e:
+            except kubernetes.client.rest.ApiException:
                 instance.report_engine_event(
                     "Encountered unexpected error while fetching pod logs for Kubernetes job {}, "
                     "Pod name {} for step {}. Will attempt to continue with other pods.".format(
@@ -541,7 +531,7 @@ def create_k8s_job_task(celery_app, **task_kwargs):
                     pipeline_run,
                     EngineEventData(
                         [
-                            EventMetadataEntry.text(step_key, "Step key"),
+                            MetadataEntry("Step key", value=step_key),
                         ],
                         error=serializable_error_info_from_exc_info(sys.exc_info()),
                     ),
@@ -549,7 +539,7 @@ def create_k8s_job_task(celery_app, **task_kwargs):
                     step_key=step_key,
                 )
 
-        events += filter_dagster_events_from_pod_logs(logs)
+        events += filter_dagster_events_from_cli_logs(logs)
         serialized_events = [serialize_dagster_namedtuple(event) for event in events]
         return serialized_events
 
